# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class TransferCycleWorkItems400Response(BaseModel):
    """
    TransferCycleWorkItems400Response
    """
    error: Optional[StrictStr] = Field(default=None, description="Error message")
    __properties = ["error"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransferCycleWorkItems400Response:
        """Create an instance of TransferCycleWorkItems400Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransferCycleWorkItems400Response:
        """Create an instance of TransferCycleWorkItems400Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TransferCycleWorkItems400Response.parse_obj(obj)

        _obj = TransferCycleWorkItems400Response.parse_obj({
            "error": obj.get("error")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.0"

# import apis into sdk package
from plane.api.assets_api import AssetsApi
from plane.api.cycles_api import CyclesApi
from plane.api.intake_api import IntakeApi
from plane.api.labels_api import LabelsApi
from plane.api.members_api import MembersApi
from plane.api.modules_api import ModulesApi
from plane.api.projects_api import ProjectsApi
from plane.api.states_api import StatesApi
from plane.api.users_api import UsersApi
from plane.api.work_item_activity_api import WorkItemActivityApi
from plane.api.work_item_attachments_api import WorkItemAttachmentsApi
from plane.api.work_item_comments_api import WorkItemCommentsApi
from plane.api.work_item_links_api import WorkItemLinksApi
from plane.api.work_item_properties_api import WorkItemPropertiesApi
from plane.api.work_item_types_api import WorkItemTypesApi
from plane.api.work_item_worklogs_api import WorkItemWorklogsApi
from plane.api.work_items_api import WorkItemsApi

# import ApiClient
from plane.api_response import ApiResponse
from plane.api_client import ApiClient
from plane.configuration import Configuration
from plane.exceptions import OpenApiException
from plane.exceptions import ApiTypeError
from plane.exceptions import ApiValueError
from plane.exceptions import ApiKeyError
from plane.exceptions import ApiAttributeError
from plane.exceptions import ApiException

# import models into sdk package
from plane.models.access_enum import AccessEnum
from plane.models.cycle import Cycle
from plane.models.cycle_create_request import CycleCreateRequest
from plane.models.cycle_issue import CycleIssue
from plane.models.cycle_issue_request_request import CycleIssueRequestRequest
from plane.models.cycle_lite import CycleLite
from plane.models.entity_type_enum import EntityTypeEnum
from plane.models.generic_asset_upload_request import GenericAssetUploadRequest
from plane.models.get_workspace_members200_response_inner import GetWorkspaceMembers200ResponseInner
from plane.models.group_enum import GroupEnum
from plane.models.intake_issue import IntakeIssue
from plane.models.intake_issue_create_request import IntakeIssueCreateRequest
from plane.models.intake_work_item_status_enum import IntakeWorkItemStatusEnum
from plane.models.issue import Issue
from plane.models.issue_activity import IssueActivity
from plane.models.issue_attachment import IssueAttachment
from plane.models.issue_attachment_upload_request import IssueAttachmentUploadRequest
from plane.models.issue_comment import IssueComment
from plane.models.issue_comment_create_request import IssueCommentCreateRequest
from plane.models.issue_expand import IssueExpand
from plane.models.issue_for_intake_request import IssueForIntakeRequest
from plane.models.issue_link import IssueLink
from plane.models.issue_link_create_request import IssueLinkCreateRequest
from plane.models.issue_property_api import IssuePropertyAPI
from plane.models.issue_property_api_request import IssuePropertyAPIRequest
from plane.models.issue_property_option_api import IssuePropertyOptionAPI
from plane.models.issue_property_option_api_request import IssuePropertyOptionAPIRequest
from plane.models.issue_property_value_api import IssuePropertyValueAPI
from plane.models.issue_property_value_api_request import IssuePropertyValueAPIRequest
from plane.models.issue_request import IssueRequest
from plane.models.issue_search import IssueSearch
from plane.models.issue_type_api import IssueTypeAPI
from plane.models.issue_type_api_request import IssueTypeAPIRequest
from plane.models.issue_work_log_api import IssueWorkLogAPI
from plane.models.issue_work_log_api_request import IssueWorkLogAPIRequest
from plane.models.label import Label
from plane.models.label_create_update_request import LabelCreateUpdateRequest
from plane.models.label_lite import LabelLite
from plane.models.module import Module
from plane.models.module_create_request import ModuleCreateRequest
from plane.models.module_issue import ModuleIssue
from plane.models.module_issue_request_request import ModuleIssueRequestRequest
from plane.models.module_lite import ModuleLite
from plane.models.module_status_enum import ModuleStatusEnum
from plane.models.network_enum import NetworkEnum
from plane.models.paginated_archived_cycle_response import PaginatedArchivedCycleResponse
from plane.models.paginated_archived_module_response import PaginatedArchivedModuleResponse
from plane.models.paginated_cycle_issue_response import PaginatedCycleIssueResponse
from plane.models.paginated_cycle_response import PaginatedCycleResponse
from plane.models.paginated_intake_issue_response import PaginatedIntakeIssueResponse
from plane.models.paginated_issue_activity_detail_response import PaginatedIssueActivityDetailResponse
from plane.models.paginated_issue_activity_response import PaginatedIssueActivityResponse
from plane.models.paginated_issue_comment_response import PaginatedIssueCommentResponse
from plane.models.paginated_issue_link_detail_response import PaginatedIssueLinkDetailResponse
from plane.models.paginated_issue_link_response import PaginatedIssueLinkResponse
from plane.models.paginated_label_response import PaginatedLabelResponse
from plane.models.paginated_module_issue_response import PaginatedModuleIssueResponse
from plane.models.paginated_module_response import PaginatedModuleResponse
from plane.models.paginated_project_response import PaginatedProjectResponse
from plane.models.paginated_state_response import PaginatedStateResponse
from plane.models.paginated_work_item_response import PaginatedWorkItemResponse
from plane.models.patched_asset_update_request import PatchedAssetUpdateRequest
from plane.models.patched_cycle_update_request import PatchedCycleUpdateRequest
from plane.models.patched_generic_asset_update_request import PatchedGenericAssetUpdateRequest
from plane.models.patched_intake_issue_update_request import PatchedIntakeIssueUpdateRequest
from plane.models.patched_issue_comment_create_request import PatchedIssueCommentCreateRequest
from plane.models.patched_issue_link_update_request import PatchedIssueLinkUpdateRequest
from plane.models.patched_issue_property_api_request import PatchedIssuePropertyAPIRequest
from plane.models.patched_issue_property_option_api_request import PatchedIssuePropertyOptionAPIRequest
from plane.models.patched_issue_request import PatchedIssueRequest
from plane.models.patched_issue_type_api_request import PatchedIssueTypeAPIRequest
from plane.models.patched_issue_work_log_api_request import PatchedIssueWorkLogAPIRequest
from plane.models.patched_label_create_update_request import PatchedLabelCreateUpdateRequest
from plane.models.patched_module_update_request import PatchedModuleUpdateRequest
from plane.models.patched_project_update_request import PatchedProjectUpdateRequest
from plane.models.patched_state_request import PatchedStateRequest
from plane.models.priority_enum import PriorityEnum
from plane.models.project import Project
from plane.models.project_create_request import ProjectCreateRequest
from plane.models.project_worklog_summary import ProjectWorklogSummary
from plane.models.property_type_enum import PropertyTypeEnum
from plane.models.relation_type_enum import RelationTypeEnum
from plane.models.retrieve_work_item_attachment400_response import RetrieveWorkItemAttachment400Response
from plane.models.state import State
from plane.models.state_lite import StateLite
from plane.models.state_request import StateRequest
from plane.models.timezone_enum import TimezoneEnum
from plane.models.transfer_cycle_issue_request_request import TransferCycleIssueRequestRequest
from plane.models.transfer_cycle_work_items200_response import TransferCycleWorkItems200Response
from plane.models.transfer_cycle_work_items400_response import TransferCycleWorkItems400Response
from plane.models.type_enum import TypeEnum
from plane.models.user_asset_upload_request import UserAssetUploadRequest
from plane.models.user_lite import UserLite



# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401

from pydantic import validate_arguments

from typing_extensions import Annotated
from pydantic import Field, StrictStr

from typing import Optional

from plane.models.generic_asset_upload_request import GenericAssetUploadRequest
from plane.models.patched_asset_update_request import PatchedAssetUpdateRequest
from plane.models.patched_generic_asset_update_request import PatchedGenericAssetUpdateRequest
from plane.models.user_asset_upload_request import UserAssetUploadRequest

from plane.api_client import ApiClient
from plane.api_response import ApiResponse
from plane.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AssetsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_generic_asset_upload(self, slug : Annotated[StrictStr, Field(..., description="Workspace slug")], generic_asset_upload_request : GenericAssetUploadRequest, **kwargs) -> None:  # noqa: E501
        """Generate presigned URL for generic asset upload  # noqa: E501

        Generate presigned URL for generic asset upload  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_generic_asset_upload(slug, generic_asset_upload_request, async_req=True)
        >>> result = thread.get()

        :param slug: Workspace slug (required)
        :type slug: str
        :param generic_asset_upload_request: (required)
        :type generic_asset_upload_request: GenericAssetUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_generic_asset_upload_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_generic_asset_upload_with_http_info(slug, generic_asset_upload_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_generic_asset_upload_with_http_info(self, slug : Annotated[StrictStr, Field(..., description="Workspace slug")], generic_asset_upload_request : GenericAssetUploadRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """Generate presigned URL for generic asset upload  # noqa: E501

        Generate presigned URL for generic asset upload  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_generic_asset_upload_with_http_info(slug, generic_asset_upload_request, async_req=True)
        >>> result = thread.get()

        :param slug: Workspace slug (required)
        :type slug: str
        :param generic_asset_upload_request: (required)
        :type generic_asset_upload_request: GenericAssetUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'slug',
            'generic_asset_upload_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_generic_asset_upload" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['slug'] is not None:
            _path_params['slug'] = _params['slug']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['generic_asset_upload_request'] is not None:
            _body_params = _params['generic_asset_upload_request']

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKeyAuthentication', 'OAuth2Authentication', 'OAuth2Authentication']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/workspaces/{slug}/assets/', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_user_asset_upload(self, user_asset_upload_request : UserAssetUploadRequest, **kwargs) -> None:  # noqa: E501
        """Generate presigned URL for user asset upload  # noqa: E501

        Generate presigned URL for user asset upload  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_user_asset_upload(user_asset_upload_request, async_req=True)
        >>> result = thread.get()

        :param user_asset_upload_request: (required)
        :type user_asset_upload_request: UserAssetUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_user_asset_upload_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_user_asset_upload_with_http_info(user_asset_upload_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_user_asset_upload_with_http_info(self, user_asset_upload_request : UserAssetUploadRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """Generate presigned URL for user asset upload  # noqa: E501

        Generate presigned URL for user asset upload  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_user_asset_upload_with_http_info(user_asset_upload_request, async_req=True)
        >>> result = thread.get()

        :param user_asset_upload_request: (required)
        :type user_asset_upload_request: UserAssetUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'user_asset_upload_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user_asset_upload" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['user_asset_upload_request'] is not None:
            _body_params = _params['user_asset_upload_request']

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKeyAuthentication', 'OAuth2Authentication', 'OAuth2Authentication']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/assets/user-assets/', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_user_asset(self, asset_id : Annotated[StrictStr, Field(..., description="Asset ID")], **kwargs) -> None:  # noqa: E501
        """Delete user asset  # noqa: E501

        Delete user asset.  Delete a user profile asset (avatar or cover image) and remove its reference from the user profile. This performs a soft delete by marking the asset as deleted and updating the user's profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_user_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param asset_id: Asset ID (required)
        :type asset_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_user_asset_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.delete_user_asset_with_http_info(asset_id, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_user_asset_with_http_info(self, asset_id : Annotated[StrictStr, Field(..., description="Asset ID")], **kwargs) -> ApiResponse:  # noqa: E501
        """Delete user asset  # noqa: E501

        Delete user asset.  Delete a user profile asset (avatar or cover image) and remove its reference from the user profile. This performs a soft delete by marking the asset as deleted and updating the user's profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_user_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param asset_id: Asset ID (required)
        :type asset_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'asset_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user_asset" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['asset_id'] is not None:
            _path_params['asset_id'] = _params['asset_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # authentication setting
        _auth_settings = ['ApiKeyAuthentication', 'OAuth2Authentication', 'OAuth2Authentication']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/assets/user-assets/{asset_id}/', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_generic_asset(self, asset_id : StrictStr, slug : Annotated[StrictStr, Field(..., description="Workspace slug")], **kwargs) -> None:  # noqa: E501
        """Get presigned URL for asset download  # noqa: E501

        Get presigned URL for asset download  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_generic_asset(asset_id, slug, async_req=True)
        >>> result = thread.get()

        :param asset_id: (required)
        :type asset_id: str
        :param slug: Workspace slug (required)
        :type slug: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_generic_asset_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_generic_asset_with_http_info(asset_id, slug, **kwargs)  # noqa: E501

    @validate_arguments
    def get_generic_asset_with_http_info(self, asset_id : StrictStr, slug : Annotated[StrictStr, Field(..., description="Workspace slug")], **kwargs) -> ApiResponse:  # noqa: E501
        """Get presigned URL for asset download  # noqa: E501

        Get presigned URL for asset download  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_generic_asset_with_http_info(asset_id, slug, async_req=True)
        >>> result = thread.get()

        :param asset_id: (required)
        :type asset_id: str
        :param slug: Workspace slug (required)
        :type slug: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'asset_id',
            'slug'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_generic_asset" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['asset_id'] is not None:
            _path_params['asset_id'] = _params['asset_id']

        if _params['slug'] is not None:
            _path_params['slug'] = _params['slug']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # authentication setting
        _auth_settings = ['ApiKeyAuthentication', 'OAuth2Authentication', 'OAuth2Authentication']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/workspaces/{slug}/assets/{asset_id}/', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_generic_asset(self, asset_id : Annotated[StrictStr, Field(..., description="Asset ID")], slug : Annotated[StrictStr, Field(..., description="Workspace slug")], patched_generic_asset_update_request : Optional[PatchedGenericAssetUpdateRequest] = None, **kwargs) -> None:  # noqa: E501
        """Update generic asset after upload completion  # noqa: E501

        Update generic asset after upload completion  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_generic_asset(asset_id, slug, patched_generic_asset_update_request, async_req=True)
        >>> result = thread.get()

        :param asset_id: Asset ID (required)
        :type asset_id: str
        :param slug: Workspace slug (required)
        :type slug: str
        :param patched_generic_asset_update_request:
        :type patched_generic_asset_update_request: PatchedGenericAssetUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the update_generic_asset_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.update_generic_asset_with_http_info(asset_id, slug, patched_generic_asset_update_request, **kwargs)  # noqa: E501

    @validate_arguments
    def update_generic_asset_with_http_info(self, asset_id : Annotated[StrictStr, Field(..., description="Asset ID")], slug : Annotated[StrictStr, Field(..., description="Workspace slug")], patched_generic_asset_update_request : Optional[PatchedGenericAssetUpdateRequest] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Update generic asset after upload completion  # noqa: E501

        Update generic asset after upload completion  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_generic_asset_with_http_info(asset_id, slug, patched_generic_asset_update_request, async_req=True)
        >>> result = thread.get()

        :param asset_id: Asset ID (required)
        :type asset_id: str
        :param slug: Workspace slug (required)
        :type slug: str
        :param patched_generic_asset_update_request:
        :type patched_generic_asset_update_request: PatchedGenericAssetUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'asset_id',
            'slug',
            'patched_generic_asset_update_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_generic_asset" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['asset_id'] is not None:
            _path_params['asset_id'] = _params['asset_id']

        if _params['slug'] is not None:
            _path_params['slug'] = _params['slug']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['patched_generic_asset_update_request'] is not None:
            _body_params = _params['patched_generic_asset_update_request']

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKeyAuthentication', 'OAuth2Authentication', 'OAuth2Authentication']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/workspaces/{slug}/assets/{asset_id}/', 'PATCH',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_user_asset(self, asset_id : Annotated[StrictStr, Field(..., description="Asset ID")], patched_asset_update_request : Optional[PatchedAssetUpdateRequest] = None, **kwargs) -> None:  # noqa: E501
        """Mark user asset as uploaded  # noqa: E501

        Mark user asset as uploaded  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_user_asset(asset_id, patched_asset_update_request, async_req=True)
        >>> result = thread.get()

        :param asset_id: Asset ID (required)
        :type asset_id: str
        :param patched_asset_update_request:
        :type patched_asset_update_request: PatchedAssetUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the update_user_asset_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.update_user_asset_with_http_info(asset_id, patched_asset_update_request, **kwargs)  # noqa: E501

    @validate_arguments
    def update_user_asset_with_http_info(self, asset_id : Annotated[StrictStr, Field(..., description="Asset ID")], patched_asset_update_request : Optional[PatchedAssetUpdateRequest] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Mark user asset as uploaded  # noqa: E501

        Mark user asset as uploaded  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_user_asset_with_http_info(asset_id, patched_asset_update_request, async_req=True)
        >>> result = thread.get()

        :param asset_id: Asset ID (required)
        :type asset_id: str
        :param patched_asset_update_request:
        :type patched_asset_update_request: PatchedAssetUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'asset_id',
            'patched_asset_update_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_asset" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['asset_id'] is not None:
            _path_params['asset_id'] = _params['asset_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['patched_asset_update_request'] is not None:
            _body_params = _params['patched_asset_update_request']

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKeyAuthentication', 'OAuth2Authentication', 'OAuth2Authentication']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/v1/assets/user-assets/{asset_id}/', 'PATCH',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import json
import re  # noqa: F401
from aenum import Enum





class TimezoneEnum(str, Enum):
    """
    * `Africa/Abidjan` - Africa/Abidjan * `Africa/Accra` - Africa/Accra * `Africa/Addis_Ababa` - Africa/Addis_Ababa * `Africa/Algiers` - Africa/Algiers * `Africa/Asmara` - Africa/Asmara * `Africa/Bamako` - Africa/Bamako * `Africa/Bangui` - Africa/Bangui * `Africa/Banjul` - Africa/Banjul * `Africa/Bissau` - Africa/Bissau * `Africa/Blantyre` - Africa/Blantyre * `Africa/Brazzaville` - Africa/Brazzaville * `Africa/Bujumbura` - Africa/Bujumbura * `Africa/Cairo` - Africa/Cairo * `Africa/Casablanca` - Africa/Casablanca * `Africa/Ceuta` - Africa/Ceuta * `Africa/Conakry` - Africa/Conakry * `Africa/Dakar` - Africa/Dakar * `Africa/Dar_es_Salaam` - Africa/Dar_es_Salaam * `Africa/Djibouti` - Africa/Djibouti * `Africa/Douala` - Africa/Douala * `Africa/El_Aaiun` - Africa/El_Aaiun * `Africa/Freetown` - Africa/Freetown * `Africa/Gaborone` - Africa/Gaborone * `Africa/Harare` - Africa/Harare * `Africa/Johannesburg` - Africa/Johannesburg * `Africa/Juba` - Africa/Juba * `Africa/Kampala` - Africa/Kampala * `Africa/Khartoum` - Africa/Khartoum * `Africa/Kigali` - Africa/Kigali * `Africa/Kinshasa` - Africa/Kinshasa * `Africa/Lagos` - Africa/Lagos * `Africa/Libreville` - Africa/Libreville * `Africa/Lome` - Africa/Lome * `Africa/Luanda` - Africa/Luanda * `Africa/Lubumbashi` - Africa/Lubumbashi * `Africa/Lusaka` - Africa/Lusaka * `Africa/Malabo` - Africa/Malabo * `Africa/Maputo` - Africa/Maputo * `Africa/Maseru` - Africa/Maseru * `Africa/Mbabane` - Africa/Mbabane * `Africa/Mogadishu` - Africa/Mogadishu * `Africa/Monrovia` - Africa/Monrovia * `Africa/Nairobi` - Africa/Nairobi * `Africa/Ndjamena` - Africa/Ndjamena * `Africa/Niamey` - Africa/Niamey * `Africa/Nouakchott` - Africa/Nouakchott * `Africa/Ouagadougou` - Africa/Ouagadougou * `Africa/Porto-Novo` - Africa/Porto-Novo * `Africa/Sao_Tome` - Africa/Sao_Tome * `Africa/Tripoli` - Africa/Tripoli * `Africa/Tunis` - Africa/Tunis * `Africa/Windhoek` - Africa/Windhoek * `America/Adak` - America/Adak * `America/Anchorage` - America/Anchorage * `America/Anguilla` - America/Anguilla * `America/Antigua` - America/Antigua * `America/Araguaina` - America/Araguaina * `America/Argentina/Buenos_Aires` - America/Argentina/Buenos_Aires * `America/Argentina/Catamarca` - America/Argentina/Catamarca * `America/Argentina/Cordoba` - America/Argentina/Cordoba * `America/Argentina/Jujuy` - America/Argentina/Jujuy * `America/Argentina/La_Rioja` - America/Argentina/La_Rioja * `America/Argentina/Mendoza` - America/Argentina/Mendoza * `America/Argentina/Rio_Gallegos` - America/Argentina/Rio_Gallegos * `America/Argentina/Salta` - America/Argentina/Salta * `America/Argentina/San_Juan` - America/Argentina/San_Juan * `America/Argentina/San_Luis` - America/Argentina/San_Luis * `America/Argentina/Tucuman` - America/Argentina/Tucuman * `America/Argentina/Ushuaia` - America/Argentina/Ushuaia * `America/Aruba` - America/Aruba * `America/Asuncion` - America/Asuncion * `America/Atikokan` - America/Atikokan * `America/Bahia` - America/Bahia * `America/Bahia_Banderas` - America/Bahia_Banderas * `America/Barbados` - America/Barbados * `America/Belem` - America/Belem * `America/Belize` - America/Belize * `America/Blanc-Sablon` - America/Blanc-Sablon * `America/Boa_Vista` - America/Boa_Vista * `America/Bogota` - America/Bogota * `America/Boise` - America/Boise * `America/Cambridge_Bay` - America/Cambridge_Bay * `America/Campo_Grande` - America/Campo_Grande * `America/Cancun` - America/Cancun * `America/Caracas` - America/Caracas * `America/Cayenne` - America/Cayenne * `America/Cayman` - America/Cayman * `America/Chicago` - America/Chicago * `America/Chihuahua` - America/Chihuahua * `America/Ciudad_Juarez` - America/Ciudad_Juarez * `America/Costa_Rica` - America/Costa_Rica * `America/Creston` - America/Creston * `America/Cuiaba` - America/Cuiaba * `America/Curacao` - America/Curacao * `America/Danmarkshavn` - America/Danmarkshavn * `America/Dawson` - America/Dawson * `America/Dawson_Creek` - America/Dawson_Creek * `America/Denver` - America/Denver * `America/Detroit` - America/Detroit * `America/Dominica` - America/Dominica * `America/Edmonton` - America/Edmonton * `America/Eirunepe` - America/Eirunepe * `America/El_Salvador` - America/El_Salvador * `America/Fort_Nelson` - America/Fort_Nelson * `America/Fortaleza` - America/Fortaleza * `America/Glace_Bay` - America/Glace_Bay * `America/Goose_Bay` - America/Goose_Bay * `America/Grand_Turk` - America/Grand_Turk * `America/Grenada` - America/Grenada * `America/Guadeloupe` - America/Guadeloupe * `America/Guatemala` - America/Guatemala * `America/Guayaquil` - America/Guayaquil * `America/Guyana` - America/Guyana * `America/Halifax` - America/Halifax * `America/Havana` - America/Havana * `America/Hermosillo` - America/Hermosillo * `America/Indiana/Indianapolis` - America/Indiana/Indianapolis * `America/Indiana/Knox` - America/Indiana/Knox * `America/Indiana/Marengo` - America/Indiana/Marengo * `America/Indiana/Petersburg` - America/Indiana/Petersburg * `America/Indiana/Tell_City` - America/Indiana/Tell_City * `America/Indiana/Vevay` - America/Indiana/Vevay * `America/Indiana/Vincennes` - America/Indiana/Vincennes * `America/Indiana/Winamac` - America/Indiana/Winamac * `America/Inuvik` - America/Inuvik * `America/Iqaluit` - America/Iqaluit * `America/Jamaica` - America/Jamaica * `America/Juneau` - America/Juneau * `America/Kentucky/Louisville` - America/Kentucky/Louisville * `America/Kentucky/Monticello` - America/Kentucky/Monticello * `America/Kralendijk` - America/Kralendijk * `America/La_Paz` - America/La_Paz * `America/Lima` - America/Lima * `America/Los_Angeles` - America/Los_Angeles * `America/Lower_Princes` - America/Lower_Princes * `America/Maceio` - America/Maceio * `America/Managua` - America/Managua * `America/Manaus` - America/Manaus * `America/Marigot` - America/Marigot * `America/Martinique` - America/Martinique * `America/Matamoros` - America/Matamoros * `America/Mazatlan` - America/Mazatlan * `America/Menominee` - America/Menominee * `America/Merida` - America/Merida * `America/Metlakatla` - America/Metlakatla * `America/Mexico_City` - America/Mexico_City * `America/Miquelon` - America/Miquelon * `America/Moncton` - America/Moncton * `America/Monterrey` - America/Monterrey * `America/Montevideo` - America/Montevideo * `America/Montserrat` - America/Montserrat * `America/Nassau` - America/Nassau * `America/New_York` - America/New_York * `America/Nome` - America/Nome * `America/Noronha` - America/Noronha * `America/North_Dakota/Beulah` - America/North_Dakota/Beulah * `America/North_Dakota/Center` - America/North_Dakota/Center * `America/North_Dakota/New_Salem` - America/North_Dakota/New_Salem * `America/Nuuk` - America/Nuuk * `America/Ojinaga` - America/Ojinaga * `America/Panama` - America/Panama * `America/Paramaribo` - America/Paramaribo * `America/Phoenix` - America/Phoenix * `America/Port-au-Prince` - America/Port-au-Prince * `America/Port_of_Spain` - America/Port_of_Spain * `America/Porto_Velho` - America/Porto_Velho * `America/Puerto_Rico` - America/Puerto_Rico * `America/Punta_Arenas` - America/Punta_Arenas * `America/Rankin_Inlet` - America/Rankin_Inlet * `America/Recife` - America/Recife * `America/Regina` - America/Regina * `America/Resolute` - America/Resolute * `America/Rio_Branco` - America/Rio_Branco * `America/Santarem` - America/Santarem * `America/Santiago` - America/Santiago * `America/Santo_Domingo` - America/Santo_Domingo * `America/Sao_Paulo` - America/Sao_Paulo * `America/Scoresbysund` - America/Scoresbysund * `America/Sitka` - America/Sitka * `America/St_Barthelemy` - America/St_Barthelemy * `America/St_Johns` - America/St_Johns * `America/St_Kitts` - America/St_Kitts * `America/St_Lucia` - America/St_Lucia * `America/St_Thomas` - America/St_Thomas * `America/St_Vincent` - America/St_Vincent * `America/Swift_Current` - America/Swift_Current * `America/Tegucigalpa` - America/Tegucigalpa * `America/Thule` - America/Thule * `America/Tijuana` - America/Tijuana * `America/Toronto` - America/Toronto * `America/Tortola` - America/Tortola * `America/Vancouver` - America/Vancouver * `America/Whitehorse` - America/Whitehorse * `America/Winnipeg` - America/Winnipeg * `America/Yakutat` - America/Yakutat * `Antarctica/Casey` - Antarctica/Casey * `Antarctica/Davis` - Antarctica/Davis * `Antarctica/DumontDUrville` - Antarctica/DumontDUrville * `Antarctica/Macquarie` - Antarctica/Macquarie * `Antarctica/Mawson` - Antarctica/Mawson * `Antarctica/McMurdo` - Antarctica/McMurdo * `Antarctica/Palmer` - Antarctica/Palmer * `Antarctica/Rothera` - Antarctica/Rothera * `Antarctica/Syowa` - Antarctica/Syowa * `Antarctica/Troll` - Antarctica/Troll * `Antarctica/Vostok` - Antarctica/Vostok * `Arctic/Longyearbyen` - Arctic/Longyearbyen * `Asia/Aden` - Asia/Aden * `Asia/Almaty` - Asia/Almaty * `Asia/Amman` - Asia/Amman * `Asia/Anadyr` - Asia/Anadyr * `Asia/Aqtau` - Asia/Aqtau * `Asia/Aqtobe` - Asia/Aqtobe * `Asia/Ashgabat` - Asia/Ashgabat * `Asia/Atyrau` - Asia/Atyrau * `Asia/Baghdad` - Asia/Baghdad * `Asia/Bahrain` - Asia/Bahrain * `Asia/Baku` - Asia/Baku * `Asia/Bangkok` - Asia/Bangkok * `Asia/Barnaul` - Asia/Barnaul * `Asia/Beirut` - Asia/Beirut * `Asia/Bishkek` - Asia/Bishkek * `Asia/Brunei` - Asia/Brunei * `Asia/Chita` - Asia/Chita * `Asia/Choibalsan` - Asia/Choibalsan * `Asia/Colombo` - Asia/Colombo * `Asia/Damascus` - Asia/Damascus * `Asia/Dhaka` - Asia/Dhaka * `Asia/Dili` - Asia/Dili * `Asia/Dubai` - Asia/Dubai * `Asia/Dushanbe` - Asia/Dushanbe * `Asia/Famagusta` - Asia/Famagusta * `Asia/Gaza` - Asia/Gaza * `Asia/Hebron` - Asia/Hebron * `Asia/Ho_Chi_Minh` - Asia/Ho_Chi_Minh * `Asia/Hong_Kong` - Asia/Hong_Kong * `Asia/Hovd` - Asia/Hovd * `Asia/Irkutsk` - Asia/Irkutsk * `Asia/Jakarta` - Asia/Jakarta * `Asia/Jayapura` - Asia/Jayapura * `Asia/Jerusalem` - Asia/Jerusalem * `Asia/Kabul` - Asia/Kabul * `Asia/Kamchatka` - Asia/Kamchatka * `Asia/Karachi` - Asia/Karachi * `Asia/Kathmandu` - Asia/Kathmandu * `Asia/Khandyga` - Asia/Khandyga * `Asia/Kolkata` - Asia/Kolkata * `Asia/Krasnoyarsk` - Asia/Krasnoyarsk * `Asia/Kuala_Lumpur` - Asia/Kuala_Lumpur * `Asia/Kuching` - Asia/Kuching * `Asia/Kuwait` - Asia/Kuwait * `Asia/Macau` - Asia/Macau * `Asia/Magadan` - Asia/Magadan * `Asia/Makassar` - Asia/Makassar * `Asia/Manila` - Asia/Manila * `Asia/Muscat` - Asia/Muscat * `Asia/Nicosia` - Asia/Nicosia * `Asia/Novokuznetsk` - Asia/Novokuznetsk * `Asia/Novosibirsk` - Asia/Novosibirsk * `Asia/Omsk` - Asia/Omsk * `Asia/Oral` - Asia/Oral * `Asia/Phnom_Penh` - Asia/Phnom_Penh * `Asia/Pontianak` - Asia/Pontianak * `Asia/Pyongyang` - Asia/Pyongyang * `Asia/Qatar` - Asia/Qatar * `Asia/Qostanay` - Asia/Qostanay * `Asia/Qyzylorda` - Asia/Qyzylorda * `Asia/Riyadh` - Asia/Riyadh * `Asia/Sakhalin` - Asia/Sakhalin * `Asia/Samarkand` - Asia/Samarkand * `Asia/Seoul` - Asia/Seoul * `Asia/Shanghai` - Asia/Shanghai * `Asia/Singapore` - Asia/Singapore * `Asia/Srednekolymsk` - Asia/Srednekolymsk * `Asia/Taipei` - Asia/Taipei * `Asia/Tashkent` - Asia/Tashkent * `Asia/Tbilisi` - Asia/Tbilisi * `Asia/Tehran` - Asia/Tehran * `Asia/Thimphu` - Asia/Thimphu * `Asia/Tokyo` - Asia/Tokyo * `Asia/Tomsk` - Asia/Tomsk * `Asia/Ulaanbaatar` - Asia/Ulaanbaatar * `Asia/Urumqi` - Asia/Urumqi * `Asia/Ust-Nera` - Asia/Ust-Nera * `Asia/Vientiane` - Asia/Vientiane * `Asia/Vladivostok` - Asia/Vladivostok * `Asia/Yakutsk` - Asia/Yakutsk * `Asia/Yangon` - Asia/Yangon * `Asia/Yekaterinburg` - Asia/Yekaterinburg * `Asia/Yerevan` - Asia/Yerevan * `Atlantic/Azores` - Atlantic/Azores * `Atlantic/Bermuda` - Atlantic/Bermuda * `Atlantic/Canary` - Atlantic/Canary * `Atlantic/Cape_Verde` - Atlantic/Cape_Verde * `Atlantic/Faroe` - Atlantic/Faroe * `Atlantic/Madeira` - Atlantic/Madeira * `Atlantic/Reykjavik` - Atlantic/Reykjavik * `Atlantic/South_Georgia` - Atlantic/South_Georgia * `Atlantic/St_Helena` - Atlantic/St_Helena * `Atlantic/Stanley` - Atlantic/Stanley * `Australia/Adelaide` - Australia/Adelaide * `Australia/Brisbane` - Australia/Brisbane * `Australia/Broken_Hill` - Australia/Broken_Hill * `Australia/Darwin` - Australia/Darwin * `Australia/Eucla` - Australia/Eucla * `Australia/Hobart` - Australia/Hobart * `Australia/Lindeman` - Australia/Lindeman * `Australia/Lord_Howe` - Australia/Lord_Howe * `Australia/Melbourne` - Australia/Melbourne * `Australia/Perth` - Australia/Perth * `Australia/Sydney` - Australia/Sydney * `Canada/Atlantic` - Canada/Atlantic * `Canada/Central` - Canada/Central * `Canada/Eastern` - Canada/Eastern * `Canada/Mountain` - Canada/Mountain * `Canada/Newfoundland` - Canada/Newfoundland * `Canada/Pacific` - Canada/Pacific * `Europe/Amsterdam` - Europe/Amsterdam * `Europe/Andorra` - Europe/Andorra * `Europe/Astrakhan` - Europe/Astrakhan * `Europe/Athens` - Europe/Athens * `Europe/Belgrade` - Europe/Belgrade * `Europe/Berlin` - Europe/Berlin * `Europe/Bratislava` - Europe/Bratislava * `Europe/Brussels` - Europe/Brussels * `Europe/Bucharest` - Europe/Bucharest * `Europe/Budapest` - Europe/Budapest * `Europe/Busingen` - Europe/Busingen * `Europe/Chisinau` - Europe/Chisinau * `Europe/Copenhagen` - Europe/Copenhagen * `Europe/Dublin` - Europe/Dublin * `Europe/Gibraltar` - Europe/Gibraltar * `Europe/Guernsey` - Europe/Guernsey * `Europe/Helsinki` - Europe/Helsinki * `Europe/Isle_of_Man` - Europe/Isle_of_Man * `Europe/Istanbul` - Europe/Istanbul * `Europe/Jersey` - Europe/Jersey * `Europe/Kaliningrad` - Europe/Kaliningrad * `Europe/Kirov` - Europe/Kirov * `Europe/Kyiv` - Europe/Kyiv * `Europe/Lisbon` - Europe/Lisbon * `Europe/Ljubljana` - Europe/Ljubljana * `Europe/London` - Europe/London * `Europe/Luxembourg` - Europe/Luxembourg * `Europe/Madrid` - Europe/Madrid * `Europe/Malta` - Europe/Malta * `Europe/Mariehamn` - Europe/Mariehamn * `Europe/Minsk` - Europe/Minsk * `Europe/Monaco` - Europe/Monaco * `Europe/Moscow` - Europe/Moscow * `Europe/Oslo` - Europe/Oslo * `Europe/Paris` - Europe/Paris * `Europe/Podgorica` - Europe/Podgorica * `Europe/Prague` - Europe/Prague * `Europe/Riga` - Europe/Riga * `Europe/Rome` - Europe/Rome * `Europe/Samara` - Europe/Samara * `Europe/San_Marino` - Europe/San_Marino * `Europe/Sarajevo` - Europe/Sarajevo * `Europe/Saratov` - Europe/Saratov * `Europe/Simferopol` - Europe/Simferopol * `Europe/Skopje` - Europe/Skopje * `Europe/Sofia` - Europe/Sofia * `Europe/Stockholm` - Europe/Stockholm * `Europe/Tallinn` - Europe/Tallinn * `Europe/Tirane` - Europe/Tirane * `Europe/Ulyanovsk` - Europe/Ulyanovsk * `Europe/Vaduz` - Europe/Vaduz * `Europe/Vatican` - Europe/Vatican * `Europe/Vienna` - Europe/Vienna * `Europe/Vilnius` - Europe/Vilnius * `Europe/Volgograd` - Europe/Volgograd * `Europe/Warsaw` - Europe/Warsaw * `Europe/Zagreb` - Europe/Zagreb * `Europe/Zurich` - Europe/Zurich * `GMT` - GMT * `Indian/Antananarivo` - Indian/Antananarivo * `Indian/Chagos` - Indian/Chagos * `Indian/Christmas` - Indian/Christmas * `Indian/Cocos` - Indian/Cocos * `Indian/Comoro` - Indian/Comoro * `Indian/Kerguelen` - Indian/Kerguelen * `Indian/Mahe` - Indian/Mahe * `Indian/Maldives` - Indian/Maldives * `Indian/Mauritius` - Indian/Mauritius * `Indian/Mayotte` - Indian/Mayotte * `Indian/Reunion` - Indian/Reunion * `Pacific/Apia` - Pacific/Apia * `Pacific/Auckland` - Pacific/Auckland * `Pacific/Bougainville` - Pacific/Bougainville * `Pacific/Chatham` - Pacific/Chatham * `Pacific/Chuuk` - Pacific/Chuuk * `Pacific/Easter` - Pacific/Easter * `Pacific/Efate` - Pacific/Efate * `Pacific/Fakaofo` - Pacific/Fakaofo * `Pacific/Fiji` - Pacific/Fiji * `Pacific/Funafuti` - Pacific/Funafuti * `Pacific/Galapagos` - Pacific/Galapagos * `Pacific/Gambier` - Pacific/Gambier * `Pacific/Guadalcanal` - Pacific/Guadalcanal * `Pacific/Guam` - Pacific/Guam * `Pacific/Honolulu` - Pacific/Honolulu * `Pacific/Kanton` - Pacific/Kanton * `Pacific/Kiritimati` - Pacific/Kiritimati * `Pacific/Kosrae` - Pacific/Kosrae * `Pacific/Kwajalein` - Pacific/Kwajalein * `Pacific/Majuro` - Pacific/Majuro * `Pacific/Marquesas` - Pacific/Marquesas * `Pacific/Midway` - Pacific/Midway * `Pacific/Nauru` - Pacific/Nauru * `Pacific/Niue` - Pacific/Niue * `Pacific/Norfolk` - Pacific/Norfolk * `Pacific/Noumea` - Pacific/Noumea * `Pacific/Pago_Pago` - Pacific/Pago_Pago * `Pacific/Palau` - Pacific/Palau * `Pacific/Pitcairn` - Pacific/Pitcairn * `Pacific/Pohnpei` - Pacific/Pohnpei * `Pacific/Port_Moresby` - Pacific/Port_Moresby * `Pacific/Rarotonga` - Pacific/Rarotonga * `Pacific/Saipan` - Pacific/Saipan * `Pacific/Tahiti` - Pacific/Tahiti * `Pacific/Tarawa` - Pacific/Tarawa * `Pacific/Tongatapu` - Pacific/Tongatapu * `Pacific/Wake` - Pacific/Wake * `Pacific/Wallis` - Pacific/Wallis * `US/Alaska` - US/Alaska * `US/Arizona` - US/Arizona * `US/Central` - US/Central * `US/Eastern` - US/Eastern * `US/Hawaii` - US/Hawaii * `US/Mountain` - US/Mountain * `US/Pacific` - US/Pacific * `UTC` - UTC
    """

    """
    allowed enum values
    """
    AFRICA_SLASH_ABIDJAN = 'Africa/Abidjan'
    AFRICA_SLASH_ACCRA = 'Africa/Accra'
    AFRICA_SLASH_ADDIS_ABABA = 'Africa/Addis_Ababa'
    AFRICA_SLASH_ALGIERS = 'Africa/Algiers'
    AFRICA_SLASH_ASMARA = 'Africa/Asmara'
    AFRICA_SLASH_BAMAKO = 'Africa/Bamako'
    AFRICA_SLASH_BANGUI = 'Africa/Bangui'
    AFRICA_SLASH_BANJUL = 'Africa/Banjul'
    AFRICA_SLASH_BISSAU = 'Africa/Bissau'
    AFRICA_SLASH_BLANTYRE = 'Africa/Blantyre'
    AFRICA_SLASH_BRAZZAVILLE = 'Africa/Brazzaville'
    AFRICA_SLASH_BUJUMBURA = 'Africa/Bujumbura'
    AFRICA_SLASH_CAIRO = 'Africa/Cairo'
    AFRICA_SLASH_CASABLANCA = 'Africa/Casablanca'
    AFRICA_SLASH_CEUTA = 'Africa/Ceuta'
    AFRICA_SLASH_CONAKRY = 'Africa/Conakry'
    AFRICA_SLASH_DAKAR = 'Africa/Dakar'
    AFRICA_SLASH_DAR_ES_SALAAM = 'Africa/Dar_es_Salaam'
    AFRICA_SLASH_DJIBOUTI = 'Africa/Djibouti'
    AFRICA_SLASH_DOUALA = 'Africa/Douala'
    AFRICA_SLASH_EL_AAIUN = 'Africa/El_Aaiun'
    AFRICA_SLASH_FREETOWN = 'Africa/Freetown'
    AFRICA_SLASH_GABORONE = 'Africa/Gaborone'
    AFRICA_SLASH_HARARE = 'Africa/Harare'
    AFRICA_SLASH_JOHANNESBURG = 'Africa/Johannesburg'
    AFRICA_SLASH_JUBA = 'Africa/Juba'
    AFRICA_SLASH_KAMPALA = 'Africa/Kampala'
    AFRICA_SLASH_KHARTOUM = 'Africa/Khartoum'
    AFRICA_SLASH_KIGALI = 'Africa/Kigali'
    AFRICA_SLASH_KINSHASA = 'Africa/Kinshasa'
    AFRICA_SLASH_LAGOS = 'Africa/Lagos'
    AFRICA_SLASH_LIBREVILLE = 'Africa/Libreville'
    AFRICA_SLASH_LOME = 'Africa/Lome'
    AFRICA_SLASH_LUANDA = 'Africa/Luanda'
    AFRICA_SLASH_LUBUMBASHI = 'Africa/Lubumbashi'
    AFRICA_SLASH_LUSAKA = 'Africa/Lusaka'
    AFRICA_SLASH_MALABO = 'Africa/Malabo'
    AFRICA_SLASH_MAPUTO = 'Africa/Maputo'
    AFRICA_SLASH_MASERU = 'Africa/Maseru'
    AFRICA_SLASH_MBABANE = 'Africa/Mbabane'
    AFRICA_SLASH_MOGADISHU = 'Africa/Mogadishu'
    AFRICA_SLASH_MONROVIA = 'Africa/Monrovia'
    AFRICA_SLASH_NAIROBI = 'Africa/Nairobi'
    AFRICA_SLASH_NDJAMENA = 'Africa/Ndjamena'
    AFRICA_SLASH_NIAMEY = 'Africa/Niamey'
    AFRICA_SLASH_NOUAKCHOTT = 'Africa/Nouakchott'
    AFRICA_SLASH_OUAGADOUGOU = 'Africa/Ouagadougou'
    AFRICA_SLASH_PORTO_MINUS_NOVO = 'Africa/Porto-Novo'
    AFRICA_SLASH_SAO_TOME = 'Africa/Sao_Tome'
    AFRICA_SLASH_TRIPOLI = 'Africa/Tripoli'
    AFRICA_SLASH_TUNIS = 'Africa/Tunis'
    AFRICA_SLASH_WINDHOEK = 'Africa/Windhoek'
    AMERICA_SLASH_ADAK = 'America/Adak'
    AMERICA_SLASH_ANCHORAGE = 'America/Anchorage'
    AMERICA_SLASH_ANGUILLA = 'America/Anguilla'
    AMERICA_SLASH_ANTIGUA = 'America/Antigua'
    AMERICA_SLASH_ARAGUAINA = 'America/Araguaina'
    AMERICA_SLASH_ARGENTINA_SLASH_BUENOS_AIRES = 'America/Argentina/Buenos_Aires'
    AMERICA_SLASH_ARGENTINA_SLASH_CATAMARCA = 'America/Argentina/Catamarca'
    AMERICA_SLASH_ARGENTINA_SLASH_CORDOBA = 'America/Argentina/Cordoba'
    AMERICA_SLASH_ARGENTINA_SLASH_JUJUY = 'America/Argentina/Jujuy'
    AMERICA_SLASH_ARGENTINA_SLASH_LA_RIOJA = 'America/Argentina/La_Rioja'
    AMERICA_SLASH_ARGENTINA_SLASH_MENDOZA = 'America/Argentina/Mendoza'
    AMERICA_SLASH_ARGENTINA_SLASH_RIO_GALLEGOS = 'America/Argentina/Rio_Gallegos'
    AMERICA_SLASH_ARGENTINA_SLASH_SALTA = 'America/Argentina/Salta'
    AMERICA_SLASH_ARGENTINA_SLASH_SAN_JUAN = 'America/Argentina/San_Juan'
    AMERICA_SLASH_ARGENTINA_SLASH_SAN_LUIS = 'America/Argentina/San_Luis'
    AMERICA_SLASH_ARGENTINA_SLASH_TUCUMAN = 'America/Argentina/Tucuman'
    AMERICA_SLASH_ARGENTINA_SLASH_USHUAIA = 'America/Argentina/Ushuaia'
    AMERICA_SLASH_ARUBA = 'America/Aruba'
    AMERICA_SLASH_ASUNCION = 'America/Asuncion'
    AMERICA_SLASH_ATIKOKAN = 'America/Atikokan'
    AMERICA_SLASH_BAHIA = 'America/Bahia'
    AMERICA_SLASH_BAHIA_BANDERAS = 'America/Bahia_Banderas'
    AMERICA_SLASH_BARBADOS = 'America/Barbados'
    AMERICA_SLASH_BELEM = 'America/Belem'
    AMERICA_SLASH_BELIZE = 'America/Belize'
    AMERICA_SLASH_BLANC_MINUS_SABLON = 'America/Blanc-Sablon'
    AMERICA_SLASH_BOA_VISTA = 'America/Boa_Vista'
    AMERICA_SLASH_BOGOTA = 'America/Bogota'
    AMERICA_SLASH_BOISE = 'America/Boise'
    AMERICA_SLASH_CAMBRIDGE_BAY = 'America/Cambridge_Bay'
    AMERICA_SLASH_CAMPO_GRANDE = 'America/Campo_Grande'
    AMERICA_SLASH_CANCUN = 'America/Cancun'
    AMERICA_SLASH_CARACAS = 'America/Caracas'
    AMERICA_SLASH_CAYENNE = 'America/Cayenne'
    AMERICA_SLASH_CAYMAN = 'America/Cayman'
    AMERICA_SLASH_CHICAGO = 'America/Chicago'
    AMERICA_SLASH_CHIHUAHUA = 'America/Chihuahua'
    AMERICA_SLASH_CIUDAD_JUAREZ = 'America/Ciudad_Juarez'
    AMERICA_SLASH_COSTA_RICA = 'America/Costa_Rica'
    AMERICA_SLASH_CRESTON = 'America/Creston'
    AMERICA_SLASH_CUIABA = 'America/Cuiaba'
    AMERICA_SLASH_CURACAO = 'America/Curacao'
    AMERICA_SLASH_DANMARKSHAVN = 'America/Danmarkshavn'
    AMERICA_SLASH_DAWSON = 'America/Dawson'
    AMERICA_SLASH_DAWSON_CREEK = 'America/Dawson_Creek'
    AMERICA_SLASH_DENVER = 'America/Denver'
    AMERICA_SLASH_DETROIT = 'America/Detroit'
    AMERICA_SLASH_DOMINICA = 'America/Dominica'
    AMERICA_SLASH_EDMONTON = 'America/Edmonton'
    AMERICA_SLASH_EIRUNEPE = 'America/Eirunepe'
    AMERICA_SLASH_EL_SALVADOR = 'America/El_Salvador'
    AMERICA_SLASH_FORT_NELSON = 'America/Fort_Nelson'
    AMERICA_SLASH_FORTALEZA = 'America/Fortaleza'
    AMERICA_SLASH_GLACE_BAY = 'America/Glace_Bay'
    AMERICA_SLASH_GOOSE_BAY = 'America/Goose_Bay'
    AMERICA_SLASH_GRAND_TURK = 'America/Grand_Turk'
    AMERICA_SLASH_GRENADA = 'America/Grenada'
    AMERICA_SLASH_GUADELOUPE = 'America/Guadeloupe'
    AMERICA_SLASH_GUATEMALA = 'America/Guatemala'
    AMERICA_SLASH_GUAYAQUIL = 'America/Guayaquil'
    AMERICA_SLASH_GUYANA = 'America/Guyana'
    AMERICA_SLASH_HALIFAX = 'America/Halifax'
    AMERICA_SLASH_HAVANA = 'America/Havana'
    AMERICA_SLASH_HERMOSILLO = 'America/Hermosillo'
    AMERICA_SLASH_INDIANA_SLASH_INDIANAPOLIS = 'America/Indiana/Indianapolis'
    AMERICA_SLASH_INDIANA_SLASH_KNOX = 'America/Indiana/Knox'
    AMERICA_SLASH_INDIANA_SLASH_MARENGO = 'America/Indiana/Marengo'
    AMERICA_SLASH_INDIANA_SLASH_PETERSBURG = 'America/Indiana/Petersburg'
    AMERICA_SLASH_INDIANA_SLASH_TELL_CITY = 'America/Indiana/Tell_City'
    AMERICA_SLASH_INDIANA_SLASH_VEVAY = 'America/Indiana/Vevay'
    AMERICA_SLASH_INDIANA_SLASH_VINCENNES = 'America/Indiana/Vincennes'
    AMERICA_SLASH_INDIANA_SLASH_WINAMAC = 'America/Indiana/Winamac'
    AMERICA_SLASH_INUVIK = 'America/Inuvik'
    AMERICA_SLASH_IQALUIT = 'America/Iqaluit'
    AMERICA_SLASH_JAMAICA = 'America/Jamaica'
    AMERICA_SLASH_JUNEAU = 'America/Juneau'
    AMERICA_SLASH_KENTUCKY_SLASH_LOUISVILLE = 'America/Kentucky/Louisville'
    AMERICA_SLASH_KENTUCKY_SLASH_MONTICELLO = 'America/Kentucky/Monticello'
    AMERICA_SLASH_KRALENDIJK = 'America/Kralendijk'
    AMERICA_SLASH_LA_PAZ = 'America/La_Paz'
    AMERICA_SLASH_LIMA = 'America/Lima'
    AMERICA_SLASH_LOS_ANGELES = 'America/Los_Angeles'
    AMERICA_SLASH_LOWER_PRINCES = 'America/Lower_Princes'
    AMERICA_SLASH_MACEIO = 'America/Maceio'
    AMERICA_SLASH_MANAGUA = 'America/Managua'
    AMERICA_SLASH_MANAUS = 'America/Manaus'
    AMERICA_SLASH_MARIGOT = 'America/Marigot'
    AMERICA_SLASH_MARTINIQUE = 'America/Martinique'
    AMERICA_SLASH_MATAMOROS = 'America/Matamoros'
    AMERICA_SLASH_MAZATLAN = 'America/Mazatlan'
    AMERICA_SLASH_MENOMINEE = 'America/Menominee'
    AMERICA_SLASH_MERIDA = 'America/Merida'
    AMERICA_SLASH_METLAKATLA = 'America/Metlakatla'
    AMERICA_SLASH_MEXICO_CITY = 'America/Mexico_City'
    AMERICA_SLASH_MIQUELON = 'America/Miquelon'
    AMERICA_SLASH_MONCTON = 'America/Moncton'
    AMERICA_SLASH_MONTERREY = 'America/Monterrey'
    AMERICA_SLASH_MONTEVIDEO = 'America/Montevideo'
    AMERICA_SLASH_MONTSERRAT = 'America/Montserrat'
    AMERICA_SLASH_NASSAU = 'America/Nassau'
    AMERICA_SLASH_NEW_YORK = 'America/New_York'
    AMERICA_SLASH_NOME = 'America/Nome'
    AMERICA_SLASH_NORONHA = 'America/Noronha'
    AMERICA_SLASH_NORTH_DAKOTA_SLASH_BEULAH = 'America/North_Dakota/Beulah'
    AMERICA_SLASH_NORTH_DAKOTA_SLASH_CENTER = 'America/North_Dakota/Center'
    AMERICA_SLASH_NORTH_DAKOTA_SLASH_NEW_SALEM = 'America/North_Dakota/New_Salem'
    AMERICA_SLASH_NUUK = 'America/Nuuk'
    AMERICA_SLASH_OJINAGA = 'America/Ojinaga'
    AMERICA_SLASH_PANAMA = 'America/Panama'
    AMERICA_SLASH_PARAMARIBO = 'America/Paramaribo'
    AMERICA_SLASH_PHOENIX = 'America/Phoenix'
    AMERICA_SLASH_PORT_MINUS_AU_MINUS_PRINCE = 'America/Port-au-Prince'
    AMERICA_SLASH_PORT_OF_SPAIN = 'America/Port_of_Spain'
    AMERICA_SLASH_PORTO_VELHO = 'America/Porto_Velho'
    AMERICA_SLASH_PUERTO_RICO = 'America/Puerto_Rico'
    AMERICA_SLASH_PUNTA_ARENAS = 'America/Punta_Arenas'
    AMERICA_SLASH_RANKIN_INLET = 'America/Rankin_Inlet'
    AMERICA_SLASH_RECIFE = 'America/Recife'
    AMERICA_SLASH_REGINA = 'America/Regina'
    AMERICA_SLASH_RESOLUTE = 'America/Resolute'
    AMERICA_SLASH_RIO_BRANCO = 'America/Rio_Branco'
    AMERICA_SLASH_SANTAREM = 'America/Santarem'
    AMERICA_SLASH_SANTIAGO = 'America/Santiago'
    AMERICA_SLASH_SANTO_DOMINGO = 'America/Santo_Domingo'
    AMERICA_SLASH_SAO_PAULO = 'America/Sao_Paulo'
    AMERICA_SLASH_SCORESBYSUND = 'America/Scoresbysund'
    AMERICA_SLASH_SITKA = 'America/Sitka'
    AMERICA_SLASH_ST_BARTHELEMY = 'America/St_Barthelemy'
    AMERICA_SLASH_ST_JOHNS = 'America/St_Johns'
    AMERICA_SLASH_ST_KITTS = 'America/St_Kitts'
    AMERICA_SLASH_ST_LUCIA = 'America/St_Lucia'
    AMERICA_SLASH_ST_THOMAS = 'America/St_Thomas'
    AMERICA_SLASH_ST_VINCENT = 'America/St_Vincent'
    AMERICA_SLASH_SWIFT_CURRENT = 'America/Swift_Current'
    AMERICA_SLASH_TEGUCIGALPA = 'America/Tegucigalpa'
    AMERICA_SLASH_THULE = 'America/Thule'
    AMERICA_SLASH_TIJUANA = 'America/Tijuana'
    AMERICA_SLASH_TORONTO = 'America/Toronto'
    AMERICA_SLASH_TORTOLA = 'America/Tortola'
    AMERICA_SLASH_VANCOUVER = 'America/Vancouver'
    AMERICA_SLASH_WHITEHORSE = 'America/Whitehorse'
    AMERICA_SLASH_WINNIPEG = 'America/Winnipeg'
    AMERICA_SLASH_YAKUTAT = 'America/Yakutat'
    ANTARCTICA_SLASH_CASEY = 'Antarctica/Casey'
    ANTARCTICA_SLASH_DAVIS = 'Antarctica/Davis'
    ANTARCTICA_SLASH_DUMONT_D_URVILLE = 'Antarctica/DumontDUrville'
    ANTARCTICA_SLASH_MACQUARIE = 'Antarctica/Macquarie'
    ANTARCTICA_SLASH_MAWSON = 'Antarctica/Mawson'
    ANTARCTICA_SLASH_MC_MURDO = 'Antarctica/McMurdo'
    ANTARCTICA_SLASH_PALMER = 'Antarctica/Palmer'
    ANTARCTICA_SLASH_ROTHERA = 'Antarctica/Rothera'
    ANTARCTICA_SLASH_SYOWA = 'Antarctica/Syowa'
    ANTARCTICA_SLASH_TROLL = 'Antarctica/Troll'
    ANTARCTICA_SLASH_VOSTOK = 'Antarctica/Vostok'
    ARCTIC_SLASH_LONGYEARBYEN = 'Arctic/Longyearbyen'
    ASIA_SLASH_ADEN = 'Asia/Aden'
    ASIA_SLASH_ALMATY = 'Asia/Almaty'
    ASIA_SLASH_AMMAN = 'Asia/Amman'
    ASIA_SLASH_ANADYR = 'Asia/Anadyr'
    ASIA_SLASH_AQTAU = 'Asia/Aqtau'
    ASIA_SLASH_AQTOBE = 'Asia/Aqtobe'
    ASIA_SLASH_ASHGABAT = 'Asia/Ashgabat'
    ASIA_SLASH_ATYRAU = 'Asia/Atyrau'
    ASIA_SLASH_BAGHDAD = 'Asia/Baghdad'
    ASIA_SLASH_BAHRAIN = 'Asia/Bahrain'
    ASIA_SLASH_BAKU = 'Asia/Baku'
    ASIA_SLASH_BANGKOK = 'Asia/Bangkok'
    ASIA_SLASH_BARNAUL = 'Asia/Barnaul'
    ASIA_SLASH_BEIRUT = 'Asia/Beirut'
    ASIA_SLASH_BISHKEK = 'Asia/Bishkek'
    ASIA_SLASH_BRUNEI = 'Asia/Brunei'
    ASIA_SLASH_CHITA = 'Asia/Chita'
    ASIA_SLASH_CHOIBALSAN = 'Asia/Choibalsan'
    ASIA_SLASH_COLOMBO = 'Asia/Colombo'
    ASIA_SLASH_DAMASCUS = 'Asia/Damascus'
    ASIA_SLASH_DHAKA = 'Asia/Dhaka'
    ASIA_SLASH_DILI = 'Asia/Dili'
    ASIA_SLASH_DUBAI = 'Asia/Dubai'
    ASIA_SLASH_DUSHANBE = 'Asia/Dushanbe'
    ASIA_SLASH_FAMAGUSTA = 'Asia/Famagusta'
    ASIA_SLASH_GAZA = 'Asia/Gaza'
    ASIA_SLASH_HEBRON = 'Asia/Hebron'
    ASIA_SLASH_HO_CHI_MINH = 'Asia/Ho_Chi_Minh'
    ASIA_SLASH_HONG_KONG = 'Asia/Hong_Kong'
    ASIA_SLASH_HOVD = 'Asia/Hovd'
    ASIA_SLASH_IRKUTSK = 'Asia/Irkutsk'
    ASIA_SLASH_JAKARTA = 'Asia/Jakarta'
    ASIA_SLASH_JAYAPURA = 'Asia/Jayapura'
    ASIA_SLASH_JERUSALEM = 'Asia/Jerusalem'
    ASIA_SLASH_KABUL = 'Asia/Kabul'
    ASIA_SLASH_KAMCHATKA = 'Asia/Kamchatka'
    ASIA_SLASH_KARACHI = 'Asia/Karachi'
    ASIA_SLASH_KATHMANDU = 'Asia/Kathmandu'
    ASIA_SLASH_KHANDYGA = 'Asia/Khandyga'
    ASIA_SLASH_KOLKATA = 'Asia/Kolkata'
    ASIA_SLASH_KRASNOYARSK = 'Asia/Krasnoyarsk'
    ASIA_SLASH_KUALA_LUMPUR = 'Asia/Kuala_Lumpur'
    ASIA_SLASH_KUCHING = 'Asia/Kuching'
    ASIA_SLASH_KUWAIT = 'Asia/Kuwait'
    ASIA_SLASH_MACAU = 'Asia/Macau'
    ASIA_SLASH_MAGADAN = 'Asia/Magadan'
    ASIA_SLASH_MAKASSAR = 'Asia/Makassar'
    ASIA_SLASH_MANILA = 'Asia/Manila'
    ASIA_SLASH_MUSCAT = 'Asia/Muscat'
    ASIA_SLASH_NICOSIA = 'Asia/Nicosia'
    ASIA_SLASH_NOVOKUZNETSK = 'Asia/Novokuznetsk'
    ASIA_SLASH_NOVOSIBIRSK = 'Asia/Novosibirsk'
    ASIA_SLASH_OMSK = 'Asia/Omsk'
    ASIA_SLASH_ORAL = 'Asia/Oral'
    ASIA_SLASH_PHNOM_PENH = 'Asia/Phnom_Penh'
    ASIA_SLASH_PONTIANAK = 'Asia/Pontianak'
    ASIA_SLASH_PYONGYANG = 'Asia/Pyongyang'
    ASIA_SLASH_QATAR = 'Asia/Qatar'
    ASIA_SLASH_QOSTANAY = 'Asia/Qostanay'
    ASIA_SLASH_QYZYLORDA = 'Asia/Qyzylorda'
    ASIA_SLASH_RIYADH = 'Asia/Riyadh'
    ASIA_SLASH_SAKHALIN = 'Asia/Sakhalin'
    ASIA_SLASH_SAMARKAND = 'Asia/Samarkand'
    ASIA_SLASH_SEOUL = 'Asia/Seoul'
    ASIA_SLASH_SHANGHAI = 'Asia/Shanghai'
    ASIA_SLASH_SINGAPORE = 'Asia/Singapore'
    ASIA_SLASH_SREDNEKOLYMSK = 'Asia/Srednekolymsk'
    ASIA_SLASH_TAIPEI = 'Asia/Taipei'
    ASIA_SLASH_TASHKENT = 'Asia/Tashkent'
    ASIA_SLASH_TBILISI = 'Asia/Tbilisi'
    ASIA_SLASH_TEHRAN = 'Asia/Tehran'
    ASIA_SLASH_THIMPHU = 'Asia/Thimphu'
    ASIA_SLASH_TOKYO = 'Asia/Tokyo'
    ASIA_SLASH_TOMSK = 'Asia/Tomsk'
    ASIA_SLASH_ULAANBAATAR = 'Asia/Ulaanbaatar'
    ASIA_SLASH_URUMQI = 'Asia/Urumqi'
    ASIA_SLASH_UST_MINUS_NERA = 'Asia/Ust-Nera'
    ASIA_SLASH_VIENTIANE = 'Asia/Vientiane'
    ASIA_SLASH_VLADIVOSTOK = 'Asia/Vladivostok'
    ASIA_SLASH_YAKUTSK = 'Asia/Yakutsk'
    ASIA_SLASH_YANGON = 'Asia/Yangon'
    ASIA_SLASH_YEKATERINBURG = 'Asia/Yekaterinburg'
    ASIA_SLASH_YEREVAN = 'Asia/Yerevan'
    ATLANTIC_SLASH_AZORES = 'Atlantic/Azores'
    ATLANTIC_SLASH_BERMUDA = 'Atlantic/Bermuda'
    ATLANTIC_SLASH_CANARY = 'Atlantic/Canary'
    ATLANTIC_SLASH_CAPE_VERDE = 'Atlantic/Cape_Verde'
    ATLANTIC_SLASH_FAROE = 'Atlantic/Faroe'
    ATLANTIC_SLASH_MADEIRA = 'Atlantic/Madeira'
    ATLANTIC_SLASH_REYKJAVIK = 'Atlantic/Reykjavik'
    ATLANTIC_SLASH_SOUTH_GEORGIA = 'Atlantic/South_Georgia'
    ATLANTIC_SLASH_ST_HELENA = 'Atlantic/St_Helena'
    ATLANTIC_SLASH_STANLEY = 'Atlantic/Stanley'
    AUSTRALIA_SLASH_ADELAIDE = 'Australia/Adelaide'
    AUSTRALIA_SLASH_BRISBANE = 'Australia/Brisbane'
    AUSTRALIA_SLASH_BROKEN_HILL = 'Australia/Broken_Hill'
    AUSTRALIA_SLASH_DARWIN = 'Australia/Darwin'
    AUSTRALIA_SLASH_EUCLA = 'Australia/Eucla'
    AUSTRALIA_SLASH_HOBART = 'Australia/Hobart'
    AUSTRALIA_SLASH_LINDEMAN = 'Australia/Lindeman'
    AUSTRALIA_SLASH_LORD_HOWE = 'Australia/Lord_Howe'
    AUSTRALIA_SLASH_MELBOURNE = 'Australia/Melbourne'
    AUSTRALIA_SLASH_PERTH = 'Australia/Perth'
    AUSTRALIA_SLASH_SYDNEY = 'Australia/Sydney'
    CANADA_SLASH_ATLANTIC = 'Canada/Atlantic'
    CANADA_SLASH_CENTRAL = 'Canada/Central'
    CANADA_SLASH_EASTERN = 'Canada/Eastern'
    CANADA_SLASH_MOUNTAIN = 'Canada/Mountain'
    CANADA_SLASH_NEWFOUNDLAND = 'Canada/Newfoundland'
    CANADA_SLASH_PACIFIC = 'Canada/Pacific'
    EUROPE_SLASH_AMSTERDAM = 'Europe/Amsterdam'
    EUROPE_SLASH_ANDORRA = 'Europe/Andorra'
    EUROPE_SLASH_ASTRAKHAN = 'Europe/Astrakhan'
    EUROPE_SLASH_ATHENS = 'Europe/Athens'
    EUROPE_SLASH_BELGRADE = 'Europe/Belgrade'
    EUROPE_SLASH_BERLIN = 'Europe/Berlin'
    EUROPE_SLASH_BRATISLAVA = 'Europe/Bratislava'
    EUROPE_SLASH_BRUSSELS = 'Europe/Brussels'
    EUROPE_SLASH_BUCHAREST = 'Europe/Bucharest'
    EUROPE_SLASH_BUDAPEST = 'Europe/Budapest'
    EUROPE_SLASH_BUSINGEN = 'Europe/Busingen'
    EUROPE_SLASH_CHISINAU = 'Europe/Chisinau'
    EUROPE_SLASH_COPENHAGEN = 'Europe/Copenhagen'
    EUROPE_SLASH_DUBLIN = 'Europe/Dublin'
    EUROPE_SLASH_GIBRALTAR = 'Europe/Gibraltar'
    EUROPE_SLASH_GUERNSEY = 'Europe/Guernsey'
    EUROPE_SLASH_HELSINKI = 'Europe/Helsinki'
    EUROPE_SLASH_ISLE_OF_MAN = 'Europe/Isle_of_Man'
    EUROPE_SLASH_ISTANBUL = 'Europe/Istanbul'
    EUROPE_SLASH_JERSEY = 'Europe/Jersey'
    EUROPE_SLASH_KALININGRAD = 'Europe/Kaliningrad'
    EUROPE_SLASH_KIROV = 'Europe/Kirov'
    EUROPE_SLASH_KYIV = 'Europe/Kyiv'
    EUROPE_SLASH_LISBON = 'Europe/Lisbon'
    EUROPE_SLASH_LJUBLJANA = 'Europe/Ljubljana'
    EUROPE_SLASH_LONDON = 'Europe/London'
    EUROPE_SLASH_LUXEMBOURG = 'Europe/Luxembourg'
    EUROPE_SLASH_MADRID = 'Europe/Madrid'
    EUROPE_SLASH_MALTA = 'Europe/Malta'
    EUROPE_SLASH_MARIEHAMN = 'Europe/Mariehamn'
    EUROPE_SLASH_MINSK = 'Europe/Minsk'
    EUROPE_SLASH_MONACO = 'Europe/Monaco'
    EUROPE_SLASH_MOSCOW = 'Europe/Moscow'
    EUROPE_SLASH_OSLO = 'Europe/Oslo'
    EUROPE_SLASH_PARIS = 'Europe/Paris'
    EUROPE_SLASH_PODGORICA = 'Europe/Podgorica'
    EUROPE_SLASH_PRAGUE = 'Europe/Prague'
    EUROPE_SLASH_RIGA = 'Europe/Riga'
    EUROPE_SLASH_ROME = 'Europe/Rome'
    EUROPE_SLASH_SAMARA = 'Europe/Samara'
    EUROPE_SLASH_SAN_MARINO = 'Europe/San_Marino'
    EUROPE_SLASH_SARAJEVO = 'Europe/Sarajevo'
    EUROPE_SLASH_SARATOV = 'Europe/Saratov'
    EUROPE_SLASH_SIMFEROPOL = 'Europe/Simferopol'
    EUROPE_SLASH_SKOPJE = 'Europe/Skopje'
    EUROPE_SLASH_SOFIA = 'Europe/Sofia'
    EUROPE_SLASH_STOCKHOLM = 'Europe/Stockholm'
    EUROPE_SLASH_TALLINN = 'Europe/Tallinn'
    EUROPE_SLASH_TIRANE = 'Europe/Tirane'
    EUROPE_SLASH_ULYANOVSK = 'Europe/Ulyanovsk'
    EUROPE_SLASH_VADUZ = 'Europe/Vaduz'
    EUROPE_SLASH_VATICAN = 'Europe/Vatican'
    EUROPE_SLASH_VIENNA = 'Europe/Vienna'
    EUROPE_SLASH_VILNIUS = 'Europe/Vilnius'
    EUROPE_SLASH_VOLGOGRAD = 'Europe/Volgograd'
    EUROPE_SLASH_WARSAW = 'Europe/Warsaw'
    EUROPE_SLASH_ZAGREB = 'Europe/Zagreb'
    EUROPE_SLASH_ZURICH = 'Europe/Zurich'
    GMT = 'GMT'
    INDIAN_SLASH_ANTANANARIVO = 'Indian/Antananarivo'
    INDIAN_SLASH_CHAGOS = 'Indian/Chagos'
    INDIAN_SLASH_CHRISTMAS = 'Indian/Christmas'
    INDIAN_SLASH_COCOS = 'Indian/Cocos'
    INDIAN_SLASH_COMORO = 'Indian/Comoro'
    INDIAN_SLASH_KERGUELEN = 'Indian/Kerguelen'
    INDIAN_SLASH_MAHE = 'Indian/Mahe'
    INDIAN_SLASH_MALDIVES = 'Indian/Maldives'
    INDIAN_SLASH_MAURITIUS = 'Indian/Mauritius'
    INDIAN_SLASH_MAYOTTE = 'Indian/Mayotte'
    INDIAN_SLASH_REUNION = 'Indian/Reunion'
    PACIFIC_SLASH_APIA = 'Pacific/Apia'
    PACIFIC_SLASH_AUCKLAND = 'Pacific/Auckland'
    PACIFIC_SLASH_BOUGAINVILLE = 'Pacific/Bougainville'
    PACIFIC_SLASH_CHATHAM = 'Pacific/Chatham'
    PACIFIC_SLASH_CHUUK = 'Pacific/Chuuk'
    PACIFIC_SLASH_EASTER = 'Pacific/Easter'
    PACIFIC_SLASH_EFATE = 'Pacific/Efate'
    PACIFIC_SLASH_FAKAOFO = 'Pacific/Fakaofo'
    PACIFIC_SLASH_FIJI = 'Pacific/Fiji'
    PACIFIC_SLASH_FUNAFUTI = 'Pacific/Funafuti'
    PACIFIC_SLASH_GALAPAGOS = 'Pacific/Galapagos'
    PACIFIC_SLASH_GAMBIER = 'Pacific/Gambier'
    PACIFIC_SLASH_GUADALCANAL = 'Pacific/Guadalcanal'
    PACIFIC_SLASH_GUAM = 'Pacific/Guam'
    PACIFIC_SLASH_HONOLULU = 'Pacific/Honolulu'
    PACIFIC_SLASH_KANTON = 'Pacific/Kanton'
    PACIFIC_SLASH_KIRITIMATI = 'Pacific/Kiritimati'
    PACIFIC_SLASH_KOSRAE = 'Pacific/Kosrae'
    PACIFIC_SLASH_KWAJALEIN = 'Pacific/Kwajalein'
    PACIFIC_SLASH_MAJURO = 'Pacific/Majuro'
    PACIFIC_SLASH_MARQUESAS = 'Pacific/Marquesas'
    PACIFIC_SLASH_MIDWAY = 'Pacific/Midway'
    PACIFIC_SLASH_NAURU = 'Pacific/Nauru'
    PACIFIC_SLASH_NIUE = 'Pacific/Niue'
    PACIFIC_SLASH_NORFOLK = 'Pacific/Norfolk'
    PACIFIC_SLASH_NOUMEA = 'Pacific/Noumea'
    PACIFIC_SLASH_PAGO_PAGO = 'Pacific/Pago_Pago'
    PACIFIC_SLASH_PALAU = 'Pacific/Palau'
    PACIFIC_SLASH_PITCAIRN = 'Pacific/Pitcairn'
    PACIFIC_SLASH_POHNPEI = 'Pacific/Pohnpei'
    PACIFIC_SLASH_PORT_MORESBY = 'Pacific/Port_Moresby'
    PACIFIC_SLASH_RAROTONGA = 'Pacific/Rarotonga'
    PACIFIC_SLASH_SAIPAN = 'Pacific/Saipan'
    PACIFIC_SLASH_TAHITI = 'Pacific/Tahiti'
    PACIFIC_SLASH_TARAWA = 'Pacific/Tarawa'
    PACIFIC_SLASH_TONGATAPU = 'Pacific/Tongatapu'
    PACIFIC_SLASH_WAKE = 'Pacific/Wake'
    PACIFIC_SLASH_WALLIS = 'Pacific/Wallis'
    US_SLASH_ALASKA = 'US/Alaska'
    US_SLASH_ARIZONA = 'US/Arizona'
    US_SLASH_CENTRAL = 'US/Central'
    US_SLASH_EASTERN = 'US/Eastern'
    US_SLASH_HAWAII = 'US/Hawaii'
    US_SLASH_MOUNTAIN = 'US/Mountain'
    US_SLASH_PACIFIC = 'US/Pacific'
    UTC = 'UTC'

    @classmethod
    def from_json(cls, json_str: str) -> TimezoneEnum: # noqa: F821
        """Create an instance of TimezoneEnum from a JSON string"""
        return TimezoneEnum(json.loads(json_str))





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, constr

class IssuePropertyOptionAPI(BaseModel):
    """
    IssuePropertyOptionAPI
    """
    id: Optional[StrictStr] = None
    deleted_at: Optional[datetime] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    name: constr(strict=True, max_length=255) = Field(...)
    sort_order: Optional[Union[StrictFloat, StrictInt]] = None
    description: Optional[StrictStr] = None
    logo_props: Optional[Any] = None
    is_active: Optional[StrictBool] = None
    is_default: Optional[StrictBool] = None
    external_source: Optional[constr(strict=True, max_length=255)] = None
    external_id: Optional[constr(strict=True, max_length=255)] = None
    created_by: Optional[StrictStr] = None
    updated_by: Optional[StrictStr] = None
    workspace: Optional[StrictStr] = None
    project: Optional[StrictStr] = None
    var_property: Optional[StrictStr] = Field(default=None, alias="property")
    parent: Optional[StrictStr] = None
    __properties = ["id", "deleted_at", "created_at", "updated_at", "name", "sort_order", "description", "logo_props", "is_active", "is_default", "external_source", "external_id", "created_by", "updated_by", "workspace", "project", "property", "parent"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IssuePropertyOptionAPI:
        """Create an instance of IssuePropertyOptionAPI from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "deleted_at",
                            "created_at",
                            "updated_at",
                            "sort_order",
                            "logo_props",
                            "created_by",
                            "updated_by",
                            "workspace",
                            "project",
                            "var_property",
                          },
                          exclude_none=True)
        # set to None if deleted_at (nullable) is None
        # and __fields_set__ contains the field
        if self.deleted_at is None and "deleted_at" in self.__fields_set__:
            _dict['deleted_at'] = None

        # set to None if logo_props (nullable) is None
        # and __fields_set__ contains the field
        if self.logo_props is None and "logo_props" in self.__fields_set__:
            _dict['logo_props'] = None

        # set to None if external_source (nullable) is None
        # and __fields_set__ contains the field
        if self.external_source is None and "external_source" in self.__fields_set__:
            _dict['external_source'] = None

        # set to None if external_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_id is None and "external_id" in self.__fields_set__:
            _dict['external_id'] = None

        # set to None if created_by (nullable) is None
        # and __fields_set__ contains the field
        if self.created_by is None and "created_by" in self.__fields_set__:
            _dict['created_by'] = None

        # set to None if updated_by (nullable) is None
        # and __fields_set__ contains the field
        if self.updated_by is None and "updated_by" in self.__fields_set__:
            _dict['updated_by'] = None

        # set to None if project (nullable) is None
        # and __fields_set__ contains the field
        if self.project is None and "project" in self.__fields_set__:
            _dict['project'] = None

        # set to None if parent (nullable) is None
        # and __fields_set__ contains the field
        if self.parent is None and "parent" in self.__fields_set__:
            _dict['parent'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IssuePropertyOptionAPI:
        """Create an instance of IssuePropertyOptionAPI from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IssuePropertyOptionAPI.parse_obj(obj)

        _obj = IssuePropertyOptionAPI.parse_obj({
            "id": obj.get("id"),
            "deleted_at": obj.get("deleted_at"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "name": obj.get("name"),
            "sort_order": obj.get("sort_order"),
            "description": obj.get("description"),
            "logo_props": obj.get("logo_props"),
            "is_active": obj.get("is_active"),
            "is_default": obj.get("is_default"),
            "external_source": obj.get("external_source"),
            "external_id": obj.get("external_id"),
            "created_by": obj.get("created_by"),
            "updated_by": obj.get("updated_by"),
            "workspace": obj.get("workspace"),
            "project": obj.get("project"),
            "var_property": obj.get("property"),
            "parent": obj.get("parent")
        })
        return _obj





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional
from pydantic import BaseModel, Field, StrictStr, constr

class IssueLink(BaseModel):
    """
    Full serializer for work item external links.  Provides complete link information including metadata and timestamps for managing external resource associations with work items.  # noqa: E501
    """
    id: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    deleted_at: Optional[datetime] = None
    title: Optional[constr(strict=True, max_length=255)] = None
    url: StrictStr = Field(...)
    metadata: Optional[Any] = None
    created_by: Optional[StrictStr] = None
    updated_by: Optional[StrictStr] = None
    project: Optional[StrictStr] = None
    workspace: Optional[StrictStr] = None
    issue: Optional[StrictStr] = None
    __properties = ["id", "created_at", "updated_at", "deleted_at", "title", "url", "metadata", "created_by", "updated_by", "project", "workspace", "issue"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IssueLink:
        """Create an instance of IssueLink from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "created_at",
                            "updated_at",
                            "created_by",
                            "updated_by",
                            "project",
                            "workspace",
                            "issue",
                          },
                          exclude_none=True)
        # set to None if deleted_at (nullable) is None
        # and __fields_set__ contains the field
        if self.deleted_at is None and "deleted_at" in self.__fields_set__:
            _dict['deleted_at'] = None

        # set to None if title (nullable) is None
        # and __fields_set__ contains the field
        if self.title is None and "title" in self.__fields_set__:
            _dict['title'] = None

        # set to None if metadata (nullable) is None
        # and __fields_set__ contains the field
        if self.metadata is None and "metadata" in self.__fields_set__:
            _dict['metadata'] = None

        # set to None if created_by (nullable) is None
        # and __fields_set__ contains the field
        if self.created_by is None and "created_by" in self.__fields_set__:
            _dict['created_by'] = None

        # set to None if updated_by (nullable) is None
        # and __fields_set__ contains the field
        if self.updated_by is None and "updated_by" in self.__fields_set__:
            _dict['updated_by'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IssueLink:
        """Create an instance of IssueLink from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IssueLink.parse_obj(obj)

        _obj = IssueLink.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "deleted_at": obj.get("deleted_at"),
            "title": obj.get("title"),
            "url": obj.get("url"),
            "metadata": obj.get("metadata"),
            "created_by": obj.get("created_by"),
            "updated_by": obj.get("updated_by"),
            "project": obj.get("project"),
            "workspace": obj.get("workspace"),
            "issue": obj.get("issue")
        })
        return _obj





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic import BaseModel, StrictBool, StrictStr, conint, constr
from plane.models.timezone_enum import TimezoneEnum

class PatchedProjectUpdateRequest(BaseModel):
    """
    Serializer for updating projects with enhanced state and estimation management.  Extends project creation with update-specific validations including default state assignment, estimation configuration, and project setting modifications.  # noqa: E501
    """
    name: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    description: Optional[StrictStr] = None
    project_lead: Optional[StrictStr] = None
    default_assignee: Optional[StrictStr] = None
    identifier: Optional[constr(strict=True, max_length=12, min_length=1)] = None
    icon_prop: Optional[Any] = None
    emoji: Optional[constr(strict=True, max_length=255)] = None
    cover_image: Optional[StrictStr] = None
    module_view: Optional[StrictBool] = None
    cycle_view: Optional[StrictBool] = None
    issue_views_view: Optional[StrictBool] = None
    page_view: Optional[StrictBool] = None
    intake_view: Optional[StrictBool] = None
    guest_view_all_features: Optional[StrictBool] = None
    archive_in: Optional[conint(strict=True, le=12, ge=0)] = None
    close_in: Optional[conint(strict=True, le=12, ge=0)] = None
    timezone: Optional[TimezoneEnum] = None
    default_state: Optional[StrictStr] = None
    estimate: Optional[StrictStr] = None
    __properties = ["name", "description", "project_lead", "default_assignee", "identifier", "icon_prop", "emoji", "cover_image", "module_view", "cycle_view", "issue_views_view", "page_view", "intake_view", "guest_view_all_features", "archive_in", "close_in", "timezone", "default_state", "estimate"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PatchedProjectUpdateRequest:
        """Create an instance of PatchedProjectUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if project_lead (nullable) is None
        # and __fields_set__ contains the field
        if self.project_lead is None and "project_lead" in self.__fields_set__:
            _dict['project_lead'] = None

        # set to None if default_assignee (nullable) is None
        # and __fields_set__ contains the field
        if self.default_assignee is None and "default_assignee" in self.__fields_set__:
            _dict['default_assignee'] = None

        # set to None if icon_prop (nullable) is None
        # and __fields_set__ contains the field
        if self.icon_prop is None and "icon_prop" in self.__fields_set__:
            _dict['icon_prop'] = None

        # set to None if emoji (nullable) is None
        # and __fields_set__ contains the field
        if self.emoji is None and "emoji" in self.__fields_set__:
            _dict['emoji'] = None

        # set to None if cover_image (nullable) is None
        # and __fields_set__ contains the field
        if self.cover_image is None and "cover_image" in self.__fields_set__:
            _dict['cover_image'] = None

        # set to None if default_state (nullable) is None
        # and __fields_set__ contains the field
        if self.default_state is None and "default_state" in self.__fields_set__:
            _dict['default_state'] = None

        # set to None if estimate (nullable) is None
        # and __fields_set__ contains the field
        if self.estimate is None and "estimate" in self.__fields_set__:
            _dict['estimate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PatchedProjectUpdateRequest:
        """Create an instance of PatchedProjectUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PatchedProjectUpdateRequest.parse_obj(obj)

        _obj = PatchedProjectUpdateRequest.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "project_lead": obj.get("project_lead"),
            "default_assignee": obj.get("default_assignee"),
            "identifier": obj.get("identifier"),
            "icon_prop": obj.get("icon_prop"),
            "emoji": obj.get("emoji"),
            "cover_image": obj.get("cover_image"),
            "module_view": obj.get("module_view"),
            "cycle_view": obj.get("cycle_view"),
            "issue_views_view": obj.get("issue_views_view"),
            "page_view": obj.get("page_view"),
            "intake_view": obj.get("intake_view"),
            "guest_view_all_features": obj.get("guest_view_all_features"),
            "archive_in": obj.get("archive_in"),
            "close_in": obj.get("close_in"),
            "timezone": obj.get("timezone"),
            "default_state": obj.get("default_state"),
            "estimate": obj.get("estimate")
        })
        return _obj





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import json
import re  # noqa: F401
from aenum import Enum





class TypeEnum(str, Enum):
    """
    * `image/jpeg` - JPEG * `image/png` - PNG * `image/webp` - WebP * `image/jpg` - JPG * `image/gif` - GIF
    """

    """
    allowed enum values
    """
    IMAGE_SLASH_JPEG = 'image/jpeg'
    IMAGE_SLASH_PNG = 'image/png'
    IMAGE_SLASH_WEBP = 'image/webp'
    IMAGE_SLASH_JPG = 'image/jpg'
    IMAGE_SLASH_GIF = 'image/gif'

    @classmethod
    def from_json(cls, json_str: str) -> TypeEnum: # noqa: F821
        """Create an instance of TypeEnum from a JSON string"""
        return TypeEnum(json.loads(json_str))





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import json
import re  # noqa: F401
from aenum import Enum





class GroupEnum(str, Enum):
    """
    * `backlog` - Backlog * `unstarted` - Unstarted * `started` - Started * `completed` - Completed * `cancelled` - Cancelled * `triage` - Triage
    """

    """
    allowed enum values
    """
    BACKLOG = 'backlog'
    UNSTARTED = 'unstarted'
    STARTED = 'started'
    COMPLETED = 'completed'
    CANCELLED = 'cancelled'
    TRIAGE = 'triage'

    @classmethod
    def from_json(cls, json_str: str) -> GroupEnum: # noqa: F821
        """Create an instance of GroupEnum from a JSON string"""
        return GroupEnum(json.loads(json_str))





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import json
import re  # noqa: F401
from aenum import Enum





class ModuleStatusEnum(str, Enum):
    """
    * `backlog` - Backlog * `planned` - Planned * `in-progress` - In Progress * `paused` - Paused * `completed` - Completed * `cancelled` - Cancelled
    """

    """
    allowed enum values
    """
    BACKLOG = 'backlog'
    PLANNED = 'planned'
    IN_MINUS_PROGRESS = 'in-progress'
    PAUSED = 'paused'
    COMPLETED = 'completed'
    CANCELLED = 'cancelled'

    @classmethod
    def from_json(cls, json_str: str) -> ModuleStatusEnum: # noqa: F821
        """Create an instance of ModuleStatusEnum from a JSON string"""
        return ModuleStatusEnum(json.loads(json_str))





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional
from pydantic import BaseModel, Field, StrictStr, constr
from plane.models.intake_work_item_status_enum import IntakeWorkItemStatusEnum
from plane.models.issue_expand import IssueExpand

class IntakeIssue(BaseModel):
    """
    Comprehensive serializer for intake work items with expanded issue details.  Provides full intake work item data including embedded issue information, status tracking, and triage metadata for issue queue management.  # noqa: E501
    """
    id: Optional[StrictStr] = None
    issue_detail: Optional[IssueExpand] = None
    inbox: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    deleted_at: Optional[datetime] = None
    status: Optional[IntakeWorkItemStatusEnum] = None
    snoozed_till: Optional[datetime] = None
    source: Optional[constr(strict=True, max_length=255)] = None
    source_email: Optional[StrictStr] = None
    external_source: Optional[constr(strict=True, max_length=255)] = None
    external_id: Optional[constr(strict=True, max_length=255)] = None
    extra: Optional[Any] = None
    created_by: Optional[StrictStr] = None
    updated_by: Optional[StrictStr] = None
    project: Optional[StrictStr] = None
    workspace: Optional[StrictStr] = None
    intake: StrictStr = Field(...)
    issue: Optional[StrictStr] = None
    duplicate_to: Optional[StrictStr] = None
    __properties = ["id", "issue_detail", "inbox", "created_at", "updated_at", "deleted_at", "status", "snoozed_till", "source", "source_email", "external_source", "external_id", "extra", "created_by", "updated_by", "project", "workspace", "intake", "issue", "duplicate_to"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IntakeIssue:
        """Create an instance of IntakeIssue from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "issue_detail",
                            "inbox",
                            "created_at",
                            "updated_at",
                            "created_by",
                            "updated_by",
                            "project",
                            "workspace",
                            "issue",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of issue_detail
        if self.issue_detail:
            _dict['issue_detail'] = self.issue_detail.to_dict()
        # set to None if deleted_at (nullable) is None
        # and __fields_set__ contains the field
        if self.deleted_at is None and "deleted_at" in self.__fields_set__:
            _dict['deleted_at'] = None

        # set to None if snoozed_till (nullable) is None
        # and __fields_set__ contains the field
        if self.snoozed_till is None and "snoozed_till" in self.__fields_set__:
            _dict['snoozed_till'] = None

        # set to None if source (nullable) is None
        # and __fields_set__ contains the field
        if self.source is None and "source" in self.__fields_set__:
            _dict['source'] = None

        # set to None if source_email (nullable) is None
        # and __fields_set__ contains the field
        if self.source_email is None and "source_email" in self.__fields_set__:
            _dict['source_email'] = None

        # set to None if external_source (nullable) is None
        # and __fields_set__ contains the field
        if self.external_source is None and "external_source" in self.__fields_set__:
            _dict['external_source'] = None

        # set to None if external_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_id is None and "external_id" in self.__fields_set__:
            _dict['external_id'] = None

        # set to None if extra (nullable) is None
        # and __fields_set__ contains the field
        if self.extra is None and "extra" in self.__fields_set__:
            _dict['extra'] = None

        # set to None if created_by (nullable) is None
        # and __fields_set__ contains the field
        if self.created_by is None and "created_by" in self.__fields_set__:
            _dict['created_by'] = None

        # set to None if updated_by (nullable) is None
        # and __fields_set__ contains the field
        if self.updated_by is None and "updated_by" in self.__fields_set__:
            _dict['updated_by'] = None

        # set to None if duplicate_to (nullable) is None
        # and __fields_set__ contains the field
        if self.duplicate_to is None and "duplicate_to" in self.__fields_set__:
            _dict['duplicate_to'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IntakeIssue:
        """Create an instance of IntakeIssue from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IntakeIssue.parse_obj(obj)

        _obj = IntakeIssue.parse_obj({
            "id": obj.get("id"),
            "issue_detail": IssueExpand.from_dict(obj.get("issue_detail")) if obj.get("issue_detail") is not None else None,
            "inbox": obj.get("inbox"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "deleted_at": obj.get("deleted_at"),
            "status": obj.get("status"),
            "snoozed_till": obj.get("snoozed_till"),
            "source": obj.get("source"),
            "source_email": obj.get("source_email"),
            "external_source": obj.get("external_source"),
            "external_id": obj.get("external_id"),
            "extra": obj.get("extra"),
            "created_by": obj.get("created_by"),
            "updated_by": obj.get("updated_by"),
            "project": obj.get("project"),
            "workspace": obj.get("workspace"),
            "intake": obj.get("intake"),
            "issue": obj.get("issue"),
            "duplicate_to": obj.get("duplicate_to")
        })
        return _obj





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import json
import re  # noqa: F401
from aenum import Enum





class PriorityEnum(str, Enum):
    """
    * `urgent` - Urgent * `high` - High * `medium` - Medium * `low` - Low * `none` - None
    """

    """
    allowed enum values
    """
    URGENT = 'urgent'
    HIGH = 'high'
    MEDIUM = 'medium'
    LOW = 'low'
    NONE = 'none'

    @classmethod
    def from_json(cls, json_str: str) -> PriorityEnum: # noqa: F821
        """Create an instance of PriorityEnum from a JSON string"""
        return PriorityEnum(json.loads(json_str))





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, constr

class IssueAttachment(BaseModel):
    """
    Serializer for work item file attachments.  Manages file asset associations with work items including metadata, storage information, and access control for document management.  # noqa: E501
    """
    id: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    deleted_at: Optional[datetime] = None
    attributes: Optional[Any] = None
    asset: StrictStr = Field(...)
    entity_type: Optional[constr(strict=True, max_length=255)] = None
    entity_identifier: Optional[constr(strict=True, max_length=255)] = None
    is_deleted: Optional[StrictBool] = None
    is_archived: Optional[StrictBool] = None
    external_id: Optional[constr(strict=True, max_length=255)] = None
    external_source: Optional[constr(strict=True, max_length=255)] = None
    size: Optional[Union[StrictFloat, StrictInt]] = None
    is_uploaded: Optional[StrictBool] = None
    storage_metadata: Optional[Any] = None
    created_by: Optional[StrictStr] = None
    updated_by: Optional[StrictStr] = None
    user: Optional[StrictStr] = None
    workspace: Optional[StrictStr] = None
    draft_issue: Optional[StrictStr] = None
    project: Optional[StrictStr] = None
    issue: Optional[StrictStr] = None
    comment: Optional[StrictStr] = None
    page: Optional[StrictStr] = None
    __properties = ["id", "created_at", "updated_at", "deleted_at", "attributes", "asset", "entity_type", "entity_identifier", "is_deleted", "is_archived", "external_id", "external_source", "size", "is_uploaded", "storage_metadata", "created_by", "updated_by", "user", "workspace", "draft_issue", "project", "issue", "comment", "page"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IssueAttachment:
        """Create an instance of IssueAttachment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "created_at",
                            "updated_at",
                            "updated_by",
                            "workspace",
                            "project",
                            "issue",
                          },
                          exclude_none=True)
        # set to None if deleted_at (nullable) is None
        # and __fields_set__ contains the field
        if self.deleted_at is None and "deleted_at" in self.__fields_set__:
            _dict['deleted_at'] = None

        # set to None if attributes (nullable) is None
        # and __fields_set__ contains the field
        if self.attributes is None and "attributes" in self.__fields_set__:
            _dict['attributes'] = None

        # set to None if entity_type (nullable) is None
        # and __fields_set__ contains the field
        if self.entity_type is None and "entity_type" in self.__fields_set__:
            _dict['entity_type'] = None

        # set to None if entity_identifier (nullable) is None
        # and __fields_set__ contains the field
        if self.entity_identifier is None and "entity_identifier" in self.__fields_set__:
            _dict['entity_identifier'] = None

        # set to None if external_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_id is None and "external_id" in self.__fields_set__:
            _dict['external_id'] = None

        # set to None if external_source (nullable) is None
        # and __fields_set__ contains the field
        if self.external_source is None and "external_source" in self.__fields_set__:
            _dict['external_source'] = None

        # set to None if storage_metadata (nullable) is None
        # and __fields_set__ contains the field
        if self.storage_metadata is None and "storage_metadata" in self.__fields_set__:
            _dict['storage_metadata'] = None

        # set to None if created_by (nullable) is None
        # and __fields_set__ contains the field
        if self.created_by is None and "created_by" in self.__fields_set__:
            _dict['created_by'] = None

        # set to None if updated_by (nullable) is None
        # and __fields_set__ contains the field
        if self.updated_by is None and "updated_by" in self.__fields_set__:
            _dict['updated_by'] = None

        # set to None if user (nullable) is None
        # and __fields_set__ contains the field
        if self.user is None and "user" in self.__fields_set__:
            _dict['user'] = None

        # set to None if workspace (nullable) is None
        # and __fields_set__ contains the field
        if self.workspace is None and "workspace" in self.__fields_set__:
            _dict['workspace'] = None

        # set to None if draft_issue (nullable) is None
        # and __fields_set__ contains the field
        if self.draft_issue is None and "draft_issue" in self.__fields_set__:
            _dict['draft_issue'] = None

        # set to None if project (nullable) is None
        # and __fields_set__ contains the field
        if self.project is None and "project" in self.__fields_set__:
            _dict['project'] = None

        # set to None if issue (nullable) is None
        # and __fields_set__ contains the field
        if self.issue is None and "issue" in self.__fields_set__:
            _dict['issue'] = None

        # set to None if comment (nullable) is None
        # and __fields_set__ contains the field
        if self.comment is None and "comment" in self.__fields_set__:
            _dict['comment'] = None

        # set to None if page (nullable) is None
        # and __fields_set__ contains the field
        if self.page is None and "page" in self.__fields_set__:
            _dict['page'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IssueAttachment:
        """Create an instance of IssueAttachment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IssueAttachment.parse_obj(obj)

        _obj = IssueAttachment.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "deleted_at": obj.get("deleted_at"),
            "attributes": obj.get("attributes"),
            "asset": obj.get("asset"),
            "entity_type": obj.get("entity_type"),
            "entity_identifier": obj.get("entity_identifier"),
            "is_deleted": obj.get("is_deleted"),
            "is_archived": obj.get("is_archived"),
            "external_id": obj.get("external_id"),
            "external_source": obj.get("external_source"),
            "size": obj.get("size"),
            "is_uploaded": obj.get("is_uploaded"),
            "storage_metadata": obj.get("storage_metadata"),
            "created_by": obj.get("created_by"),
            "updated_by": obj.get("updated_by"),
            "user": obj.get("user"),
            "workspace": obj.get("workspace"),
            "draft_issue": obj.get("draft_issue"),
            "project": obj.get("project"),
            "issue": obj.get("issue"),
            "comment": obj.get("comment"),
            "page": obj.get("page")
        })
        return _obj





# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import json
import re  # noqa: F401
from aenum import Enum





class NetworkEnum(int, Enum):
    """
    * `0` - Secret * `2` - Public
    """

    """
    allowed enum values
    """
    NUMBER_0 = 0
    NUMBER_2 = 2

    @classmethod
    def from_json(cls, json_str: str) -> NetworkEnum: # noqa: F821
        """Create an instance of NetworkEnum from a JSON string"""
        return NetworkEnum(json.loads(json_str))


